@@ -7,7 +7,8 @@ set -x
 export ARROW_HOME=$PREFIX
 export PARQUET_HOME=$PREFIX
 
+
 cd python
 $PYTHON setup.py \
-        build_ext --build-type=release --with-parquet --with-jemalloc \
+        build_ext --build-type=release --with-parquet \
         install --single-version-externally-managed --record=record.txt
